from setuptools import setup
setup(name='jarviscloud',
version='0.1',
description='Testing installation of Package',
url='https://github.com/selvakumar-sss/jarvis_pause.git',
author='selvakumar',
author_email='eyesway@gmail.com',
license='MIT',
packages=['jarviscloud'],
zip_safe=False)